<?php

namespace Drupal\Tests\testsuite\Unit;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\Config;
use Drupal\Core\Form\FormState;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\testsuite\Form\ConfigurationForm;
use Drupal\testsuite\ConfigService;
use Drupal\testsuite\InitializerService;
use Drupal\Tests\UnitTestCase;

/**
 * Test class for Drupal\testsuite\Form\ConfigurationForm
 *
 */
class TestSuiteConfigFormTest extends UnitTestCase {

  /**
   * @var \Drupal\Core\StringTranslation\TranslationInterface
   */
  private $translationInterfaceMock;

  /**
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private $configFactoryMock;

  /**
   * @var \Drupal\Core\Config\Config
   */
  private $configMock;

  /**
   * @var \Drupal\testsuite\Form\ConfigurationForm
   */
  private $form;

  public function setUp(): void {
    // prophesize() is made available via extension from UnitTestCase
    // Call this method to create a mock based on a class
    $this->translationInterfaceMock = $this->prophesize(TranslationInterface::class);

    // Create mock to return config that will be used in the code under test
    $this->configMock = $this->prophesize(Config::class);

    $configService = $this->getMockBuilder(ConfigService::class)->getMock();
    $initializerService = $this->getMockBuilder(InitializerService::class)->setConstructorArgs([$configService])->getMock();
    // When the get method of the config is called with the parameter 'custom_property',
    // the array ['label' => 'Discounts'] will be returned.
    $this->configMock->get('testsuite_mysql_storage_type')->willReturn([
      'label' => 'Storage Type'
    ]);

    $this->configFactoryMock = $this->prophesize(ConfigFactoryInterface::class);
    $this->configFactoryMock->getEditable('testsuite.settings')->willReturn($this->configMock);



    // Instantiate the code under test
    $this->form = new ConfigurationForm($initializerService);
    // Config Base Form has a call to $this->t() which references the TranslationService
    // Set the translation service mock so that the program won't throw an error
    $this->form->setStringTranslation($this->translationInterfaceMock->reveal());
  }

  // Test that the correct form ID is returned
  public function testFormId() {
    $this->assertEquals('testsuite_settings', $this->form->getFormId());
  }
}
